@@ -3,6 +3,9 @@ import time
 
 import requests
 
+from npc_internal.logger import logger
+
+
 API_HOST = 'http://localhost:8000'
 
 cache = {}
@@ -15,7 +18,7 @@ def random_apikey():
 
 def set_apikey(set_apikey):
     global _apikey
-    print('have: %s, set: %s' % (_apikey, set_apikey))
+    logger.debug('have: %s, set: %s' % (_apikey, set_apikey))
     if _apikey and set_apikey != _apikey:
         raise Exception('already set api key')
     _apikey = set_apikey
@@ -35,23 +38,24 @@ def get_server_url():
     if cached_value:
         return cached_value
 
+    print('cloudpy: connecting to the cloud')
     url = '%s/api/instances/init' % API_HOST
     params = {'apikey': apikey}
-    print('params', params)
+    logger.debug('params', params)
     resp = requests.post(url, data=params)
-    print(resp)
+    logger.debug(resp)
     data = resp.json()
     for i in range(100):
         host = data.get('host')
         status = data.get('status')
         if host and status == 'running':
             break
-        print('initializing, host=%s, status=%s' % (host, status))
+        print('cloudpy: initializing, host=%s, status=%s' % (host, status))
         host = None
         time.sleep(2)
     if not host:
         raise Exception('unable to get a cloudpy host')
     url = 'http://%s:9090' % host
-    print('got url --> %s' % url)
+    logger.debug('got url --> %s' % url)
     cache[apikey] = url
     return url
