@@ -24,7 +24,7 @@ def get_factory_singleton():
 
 def remote_init(server_url, base_classname, args, kwargs):
     req = Request(None, '', 'init', args, kwargs, {'class': base_classname})
-    with ServerProxy(server_url, allow_none=True) as server:
+    with ServerProxy(api.get_server_url(), allow_none=True) as server:
         proxy_id = ProxyId.deserialize(server.init(req.serialize()))
     return proxy_id
 
@@ -33,16 +33,9 @@ class ProxySpec(object):
 
     def __init__(self, server_url, module_proxy_id, factory):
         self.server_url = server_url
-        # self._server_url = None
         self.module_proxy_id = module_proxy_id
         self.factory = factory
 
-    # @property
-    # def server_url(self):
-    #     if not self._server_url:
-    #         self._server_url = api.get_server_url()
-    #     return self._server_url
-
 
 class ProxyFactory(object):
 
@@ -131,11 +124,7 @@ class ProxyFactory(object):
             raise Exception("didn't find base module for %s, %s" % (
                 proxy_module, proxy_fullname))
 
-        # print('proxy_fullname:', proxy_fullname)
-
         for field_name in dir(base_module):
-            # print('-', field_name)
-
             field = getattr(base_module, field_name)
             full_field_name = proxy_module.__name__ + '.' + field_name
 
@@ -146,15 +135,7 @@ class ProxyFactory(object):
                 if proxy_name in self.modules:
                     proxy_field = self.modules[proxy_name]
                     ok = True
-            # print('ok?', ok)
             if not ok:
-
-                # if proxy_fullname == 'pandas_cloud.core.computation.expr' and field_name == 'Expr':
-                #     import pdb ; pdb.set_trace()
-
-                # if inspect.isclass(field):
-                #     print('FOUND A CLASS: %s %s' % (proxy_fullname, field_name))
-
                 field_name = full_field_name.rpartition('.')[2]
                 if field_name in ['__name__']:
                     proxy_field = full_field_name.rpartition('.')[0]
@@ -172,7 +153,6 @@ class ProxyFactory(object):
                     ok =False
                 elif inspect.isclass(field) and get_fullname(field) in class_specs:
                     full_classname = get_fullname(field)
-                    # print('found a class: %s' % (full_classname))
                     if not self.has_class(full_classname):
                         clazz = create_proxy_class(field, class_specs, spec)
                         self.add_class(full_classname, clazz)
@@ -189,7 +169,6 @@ class ProxyFactory(object):
                     if like_method:
                         call_as = 'method'
                         fn = ProxyFunction(base_module, field_name, spec)
-                        # print('FOUND A FUNCTION: %s %s' % (proxy_fullname, field_name))
                     else:
                         # TODO: should probably proxy these as well
                         call_as = 'attr'
@@ -210,16 +189,14 @@ class ProxyAttribute(object):
         self.spec = spec
 
     def _req(self, obj, remote_method, remote_args):
-        # proxy_id = obj._proxy_id
         proxy_id = get_proxy_id(obj)
         req = Request(proxy_id, remote_method, 'method', remote_args, {})
         logger.debug('Sending property request: %s', req)
-        with ServerProxy(self.spec.server_url, allow_none=True) as server:
+        with ServerProxy(api.get_server_url(), allow_none=True) as server:
             resp = Response.deserialize(server.proxy(req.serialize()))
         return resp.unpack(self.spec.factory)
 
     def __get__(self, obj, objtype=None):
-        # import pdb ; pdb.set_trace()
         return self._req(obj, '__getattribute__', [self.name])
 
     def __set__(self, obj, value):
@@ -237,16 +214,12 @@ class ProxyAttributeGetter(object):
             if name in local or name == '_x':
                 logger.debug('Proxy attr getter: return "%s" from local' % name)
                 val = object.__getattribute__(self, name)
-                # if name in should_proxy and proxy_id and not get_proxy_id(val):
-                #     logger.debug('%s has an existing proxy id: %s' % (type(self), proxy_id))
-                #     attr_proxy_id = proxy_id.for_child(name)
-                #     set_proxy_id(val, attr_proxy_id)
                 return val
 
             proxy_id = get_proxy_id(self)
             req = Request(proxy_id, '__getattribute__', 'method', [name], {})
             logger.debug('Sending attribute getter: %s', req)
-            with ServerProxy(spec.server_url, allow_none=True) as server:
+            with ServerProxy(self.spec.server_url, allow_none=True) as server:
                 resp = Response.deserialize(server.proxy(req.serialize()))
                 logger.debug('Response: %s', resp)
             return resp.unpack(spec.factory)
@@ -261,15 +234,10 @@ class ProxyInstanceMethod(object):
 
     def __init__(self, name, spec):
         def fn(self, *args, **kwargs):
-            # if name == 'apply':
-            #     import pdb ; pdb.set_trace()
             proxy_id = get_proxy_id(self)
             req = Request(proxy_id, name, 'method', args, kwargs)
             logger.debug('Sending instance method %s', req)
-            server_url = api.get_server_url()
-            # server_url = spec.server_url
-            print('using url:', server_url)
-            with ServerProxy(server_url, allow_none=True) as server:
+            with ServerProxy(api.get_server_url(), allow_none=True) as server:
                 resp = Response.deserialize(server.proxy(req.serialize()))
                 logger.debug('Got response %s', resp)
             return resp.unpack(spec.factory)
@@ -303,7 +271,7 @@ class ProxyStaticMethod(object):
             proxy_id = spec.module_proxy_id
             req = Request(proxy_id, name, 'method', args, kwargs)
             logger.debug('Sending static method %s', req)
-            with ServerProxy(spec.server_url, allow_none=True) as server:
+            with ServerProxy(api.get_server_url(), allow_none=True) as server:
                 resp = Response.deserialize(server.proxy(req.serialize()))
                 logger.debug('Got response %s', resp)
             return resp.unpack(spec.factory)
@@ -328,7 +296,7 @@ class ProxyClassMethod(object):
             proxy_id = spec.module_proxy_id
             req = Request(proxy_id, name, 'classmethod', args, kwargs)
             logger.debug('Sending class method %s', req)
-            with ServerProxy(spec.server_url, allow_none=True) as server:
+            with ServerProxy(api.get_server_url(), allow_none=True) as server:
                 resp = Response.deserialize(server.proxy(req.serialize()))
                 logger.debug('Got response %s', resp)
             return resp.unpack(spec.factory)
@@ -363,9 +331,7 @@ class ProxyFunction(object):
     def __call__(self, *args, **kwargs):
         req = Request(self.proxy_id, None, 'method', args, kwargs)
         logger.debug('Sending method %s', req)
-        url = api.get_server_url()
-        logger.debug('Using URL: %s' % url)
-        with ServerProxy(url, allow_none=True) as server:
+        with ServerProxy(api.get_server_url(), allow_none=True) as server:
             resp = Response.deserialize(server.proxy(req.serialize()))
             logger.debug('Got response %s', resp)
         return resp.unpack(self.spec.factory)
@@ -378,8 +344,6 @@ class ProxyClassMeta(type):
     def __call__(cls, *args, **kwargs):
         logger.debug('ProxyClassMeta making new class %s with: %s and %s' % (
             cls.__name__, args, kwargs))
-        # server_url = cls._proxy_server_url
-
         server_url = api.get_server_url()
         if 'proxy_id' in kwargs:
             proxy_id = kwargs['proxy_id']
